@@ -19,7 +19,7 @@ class ThreadWithReturnValue(Thread):
 
 
 def convert_str_to_number(x: str) -> int:
-    """ convert numbers in human-readable format (like -21k) to int """
+    """ convert numbers fron human-readable format (like -21k) to int """
     total_stars = 0
     num_map = {'K': 1000, 'M': 1000000, 'B': 1000000000}
     x = x.replace(',', '.')
